==> conf-ini-g-2023.13.tar.gz: conf-ini-g-2023.13/conf_ini_g/catalog/interface/window/parameter/none.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from __future__ import annotations

import dataclasses as dtcl
from typing import Any

from conf_ini_g.interface.window.backend import backend_t, label_wgt_h
from conf_ini_g.specification.parameter.main import parameter_t
from conf_ini_g.specification.parameter.type import type_t


@dtcl.dataclass(slots=True, repr=False, eq=False)
class none_wgt_t:
    library_wgt: label_wgt_h

    @classmethod
    def NewWithDetails(
        cls, _: Any, __: type_t | None, backend: backend_t, ___: parameter_t | None, /
    ) -> none_wgt_t:
        """"""
        return cls(library_wgt=backend.label_wgt_t("None"))

    def Text(self) -> str:
        """"""
        return "None"

==> conf-ini-g-2023.22.tar.gz: conf-ini-g-2023.22/conf_ini_g/catalog/interface/window/parameter/none.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from __future__ import annotations

import dataclasses as dtcl
from typing import Any

from babelwidget.main import backend_t, label_wgt_h

from conf_ini_g.interface.window.generic import parameter_a


@dtcl.dataclass(slots=True, repr=False, eq=False)
class none_wgt_t(parameter_a):
    library_wgt: label_wgt_h

    @classmethod
    def NewWithDetails(
        cls, _: Any, __: Any | None, backend: backend_t, ___: Any | None, /
    ) -> none_wgt_t:
        """"""
        return cls(library_wgt=backend.label_wgt_t("None"))

    def Assign(self, _: Any, __: Any | None, /) -> None:
        """"""
        pass

    def Text(self) -> str:
        """"""
        return "None"
